==> zio-aws-kinesisanalyticsv2_3-5.17.144.1-sources.jar: zio/aws/kinesisanalyticsv2/model/FlinkRunConfiguration.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.BooleanObject
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class FlinkRunConfiguration(
    allowNonRestoredState: Option[BooleanObject] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.FlinkRunConfiguration = {
    import FlinkRunConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.FlinkRunConfiguration
      .builder()
      .optionallyWith(
        allowNonRestoredState.map(value => value: java.lang.Boolean)
      )(_.allowNonRestoredState)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalyticsv2.model.FlinkRunConfiguration.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.FlinkRunConfiguration.wrap(buildAwsValue())
}
object FlinkRunConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.FlinkRunConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalyticsv2.model.FlinkRunConfiguration =
      zio.aws.kinesisanalyticsv2.model
        .FlinkRunConfiguration(allowNonRestoredState.map(value => value))
    def allowNonRestoredState: Option[BooleanObject]
    def getAllowNonRestoredState: ZIO[Any, AwsError, BooleanObject] =
      AwsError.unwrapOptionField("allowNonRestoredState", allowNonRestoredState)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.FlinkRunConfiguration
  ) extends zio.aws.kinesisanalyticsv2.model.FlinkRunConfiguration.ReadOnly {
    override val allowNonRestoredState: Option[BooleanObject] = scala
      .Option(impl.allowNonRestoredState())
      .map(value => value: BooleanObject)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.FlinkRunConfiguration
  ): zio.aws.kinesisanalyticsv2.model.FlinkRunConfiguration.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kinesisanalyticsv2_3-5.19.33.1-sources.jar: zio/aws/kinesisanalyticsv2/model/FlinkRunConfiguration.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.BooleanObject
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class FlinkRunConfiguration(
    allowNonRestoredState: Optional[BooleanObject] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.FlinkRunConfiguration = {
    import FlinkRunConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.FlinkRunConfiguration
      .builder()
      .optionallyWith(
        allowNonRestoredState.map(value => value: java.lang.Boolean)
      )(_.allowNonRestoredState)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalyticsv2.model.FlinkRunConfiguration.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.FlinkRunConfiguration.wrap(buildAwsValue())
}
object FlinkRunConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.FlinkRunConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalyticsv2.model.FlinkRunConfiguration =
      zio.aws.kinesisanalyticsv2.model
        .FlinkRunConfiguration(allowNonRestoredState.map(value => value))
    def allowNonRestoredState: Optional[BooleanObject]
    def getAllowNonRestoredState: ZIO[Any, AwsError, BooleanObject] =
      AwsError.unwrapOptionField("allowNonRestoredState", allowNonRestoredState)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.FlinkRunConfiguration
  ) extends zio.aws.kinesisanalyticsv2.model.FlinkRunConfiguration.ReadOnly {
    override val allowNonRestoredState: Optional[BooleanObject] =
      zio.aws.core.internal
        .optionalFromNullable(impl.allowNonRestoredState())
        .map(value => value: BooleanObject)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.FlinkRunConfiguration
  ): zio.aws.kinesisanalyticsv2.model.FlinkRunConfiguration.ReadOnly =
    new Wrapper(impl)
}
